Struct cargo_scaffold::ScaffoldDescription
source · pub struct ScaffoldDescription { /* private fields */ }Implementations
sourceimpl ScaffoldDescription
impl ScaffoldDescription
pub fn new(opts: Opts) -> Result<Self>
pub fn name(&self) -> Option<String>
sourcepub fn fetch_parameters_value(&self) -> Result<BTreeMap<String, Value>>
pub fn fetch_parameters_value(&self) -> Result<BTreeMap<String, Value>>
Launch prompt to the user to ask for different parameters
sourcepub fn scaffold_with_parameters(
&self,
parameters: BTreeMap<String, Value>
) -> Result<()>
pub fn scaffold_with_parameters( &self, parameters: BTreeMap<String, Value> ) -> Result<()>
Scaffold the project with the given parameters defined in the .scaffold.toml without prompting any inputs It’s a non-interactive mode
pub fn run_cmd(cmd: &str) -> Result<()>
pub fn setup_cmd(cmd: &str) -> Result<Command>