Struct cargo_scaffold::Opts
source · pub struct Opts {
pub template_path: PathBuf,
pub repository_template_path: Option<PathBuf>,
pub git_ref: Option<String>,
pub project_name: Option<String>,
pub target_dir: Option<PathBuf>,
pub force: bool,
pub append: bool,
pub passphrase_needed: bool,
pub private_key_path: Option<PathBuf>,
pub parameters: Vec<String>,
}Fields
template_path: PathBufSpecifiy your template location
repository_template_path: Option<PathBuf>Specifiy your template location in the repository if it’s not located at the root of your repository
git_ref: Option<String>Full commit hash, tag or branch from which the template is cloned (i.e.: “deed14dcbf17ba87f6659ea05755cf94cb1464ab” or “v0.5.0” or “main”)
project_name: Option<String>Specify the name of your generated project (and so skip the prompt asking for it)
target_dir: Option<PathBuf>Specifiy the target directory
force: boolOverride target directory if it exists
append: boolAppend files in the target directory, create directory with the project name if it doesn’t already exist but doesn’t overwrite existing file (use force for that kind of usage)
passphrase_needed: boolIgnored, kept for backwards compatibility [DEPRECATED]
private_key_path: Option<PathBuf>Specify if your private SSH key is located in another location than $HOME/.ssh/id_rsa
parameters: Vec<String>Supply parameters via the command line in
Implementations